# Calculate a hash of the source files to which any changes might
# constitute an ABI change. This causes more false-positives than
# header_signature.bbclass but it doesn't change between MACHINEs and
# is much easier to generate.

IGNORE_SOURCE_ABI_SIGNATURE ?= "0"
SOURCE_ABI_PRUNE ?= "-false"

do_source_abi_signature() {
    set -x
    cd ${S}

    # This generates a sorted list of files which are hashed
    # individually by sha1sum to generate a "manifest". This
    # "manifest" is then itself hashed to yield a single hash that is
    # used for comparison.
    calculated="`find . \( \( ${SOURCE_ABI_PRUNE} \) -prune \) -o \( -type f -iname '*.h' -print0 \)|sort -z|xargs -0 sha1sum|sha1sum -|cut -c-40`"

    # This magic number is what you get if you run "find . -type f | xargs -0 sha1sum | sha1sum" in an empty directory.
    if [ "$calculated" = "5cd337198ead0768975610a135e26257153198c7" ]; then
        echo "Header signature indicates no files were checksummed!"
	echo "Maybe your clone has failed or PV contains a spurious -local."
	exit 1
    fi
    
    if [ "$calculated" != "${SOURCE_ABI_SIGNATURE}" ]; then
        echo "Header signature mismatch" 1>&2
        echo "  Calculated: $calculated" 1>&2
        echo "  Expected:   ${SOURCE_ABI_SIGNATURE}" 1>&2
        if [ "${IGNORE_SOURCE_ABI_SIGNATURE}" = "0" ]; then
            exit 1
        fi
    fi
}

addtask do_source_abi_signature after do_patch before do_package

# People won't notice that they've changed the signatures if they use
# purely nfsquick unless we add the task here

NFSQUICK_FUNCS += "do_source_abi_signature"
